@@ -64,6 +64,7 @@ import logging
 from pathlib import Path
 import shutil
 from typing import Union, Optional
+from numbers import Number
 import pandas as pd
 from .RasPrj import RasPrj, ras
 from .RasUtils import RasUtils
@@ -85,13 +86,13 @@ class RasPlan:
     
     @staticmethod
     @log_call
-    def set_geom(plan_number: Union[str, int], new_geom: Union[str, int], ras_object=None) -> pd.DataFrame:
+    def set_geom(plan_number: Union[str, Number], new_geom: Union[str, Number], ras_object=None) -> pd.DataFrame:
         """
         Set the geometry for the specified plan by updating only the plan file.
 
         Parameters:
-            plan_number (Union[str, int]): The plan number to update.
-            new_geom (Union[str, int]): The new geometry number to set.
+            plan_number (Union[str, Number]): The plan number to update (accepts int, float, numpy types, etc.).
+            new_geom (Union[str, Number]): The new geometry number to set (accepts int, float, numpy types, etc.).
             ras_object: An optional RAS object instance.
 
         Returns:
@@ -107,8 +108,9 @@ class RasPlan:
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
 
-        plan_number = str(plan_number).zfill(2)
-        new_geom = str(new_geom).zfill(2)
+        # Normalize plan and geometry numbers to two-digit format
+        plan_number = RasUtils.normalize_ras_number(plan_number)
+        new_geom = RasUtils.normalize_ras_number(new_geom)
 
         # Update all dataframes
         ras_obj.plan_df = ras_obj.get_plan_entries()
@@ -156,13 +158,13 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def set_steady(plan_number: str, new_steady_flow_number: str, ras_object=None):
+    def set_steady(plan_number: Union[str, Number], new_steady_flow_number: Union[str, Number], ras_object=None):
         """
         Apply a steady flow file to a plan file.
-        
+
         Parameters:
-        plan_number (str): Plan number (e.g., '02')
-        new_steady_flow_number (str): Steady flow number to apply (e.g., '01')
+        plan_number (Union[str, Number]): Plan number (e.g., '02', 2, or 2.0)
+        new_steady_flow_number (Union[str, Number]): Steady flow number to apply (e.g., '01', 1, or 1.0)
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
         
         Returns:
@@ -180,9 +182,13 @@ class RasPlan:
         """
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
-                        
+
+        # Normalize plan and flow numbers to two-digit format
+        plan_number = RasUtils.normalize_ras_number(plan_number)
+        new_steady_flow_number = RasUtils.normalize_ras_number(new_steady_flow_number)
+
         ras_obj.flow_df = ras_obj.get_flow_entries()
-        
+
         if new_steady_flow_number not in ras_obj.flow_df['flow_number'].values:
             raise ValueError(f"Steady flow number {new_steady_flow_number} not found in project file.")
         
@@ -217,13 +223,13 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def set_unsteady(plan_number: str, new_unsteady_flow_number: str, ras_object=None):
+    def set_unsteady(plan_number: Union[str, Number], new_unsteady_flow_number: Union[str, Number], ras_object=None):
         """
         Apply an unsteady flow file to a plan file.
-        
+
         Parameters:
-        plan_number (str): Plan number (e.g., '04')
-        new_unsteady_flow_number (str): Unsteady flow number to apply (e.g., '01')
+        plan_number (Union[str, Number]): Plan number (e.g., '04', 4, or 4.0)
+        new_unsteady_flow_number (Union[str, Number]): Unsteady flow number to apply (e.g., '01', 1, or 1.0)
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
         
         Returns:
@@ -241,9 +247,13 @@ class RasPlan:
         """
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
-        
+
+        # Normalize plan and unsteady flow numbers to two-digit format
+        plan_number = RasUtils.normalize_ras_number(plan_number)
+        new_unsteady_flow_number = RasUtils.normalize_ras_number(new_unsteady_flow_number)
+
         ras_obj.unsteady_df = ras_obj.get_unsteady_entries()
-        
+
         if new_unsteady_flow_number not in ras_obj.unsteady_df['unsteady_number'].values:
             raise ValueError(f"Unsteady number {new_unsteady_flow_number} not found in project file.")
         
@@ -290,12 +300,12 @@ class RasPlan:
     
     @staticmethod
     @log_call
-    def set_num_cores(plan_number, num_cores, ras_object=None):
+    def set_num_cores(plan_number: Union[str, Number], num_cores: int, ras_object=None):
         """
         Update the maximum number of cores to use in the HEC-RAS plan file.
-        
+
         Parameters:
-        plan_number (str): Plan number (e.g., '02') or full path to the plan file
+        plan_number (Union[str, Number]): Plan number (e.g., '02', 2, or 2.0) or full path to the plan file
         num_cores (int): Maximum number of cores to use
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
         
@@ -420,12 +430,12 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def get_results_path(plan_number: str, ras_object=None) -> Optional[str]:
+    def get_results_path(plan_number: Union[str, Number], ras_object=None) -> Optional[str]:
         """
         Retrieve the results file path for a given HEC-RAS plan number.
 
         Args:
-            plan_number (str): The HEC-RAS plan number for which to find the results path.
+            plan_number (Union[str, Number]): The HEC-RAS plan number for which to find the results path (e.g., '02', 2, or 2.0).
             ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
 
         Returns:
@@ -447,9 +457,9 @@ class RasPlan:
         
         # Update the plan dataframe in the ras instance to ensure it is current
         ras_obj.plan_df = ras_obj.get_plan_entries()
-        
-        # Ensure plan_number is a string
-        plan_number = str(plan_number).zfill(2)
+
+        # Normalize plan number to two-digit format
+        plan_number = RasUtils.normalize_ras_number(plan_number)
         
         plan_entry = ras_obj.plan_df[ras_obj.plan_df['plan_number'] == plan_number]
         if not plan_entry.empty:
@@ -463,20 +473,20 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def get_plan_path(plan_number: str, ras_object=None) -> Optional[str]:
+    def get_plan_path(plan_number: Union[str, Number], ras_object=None) -> Optional[str]:
         """
         Return the full path for a given plan number.
-        
+
         This method ensures that the latest plan entries are included by refreshing
         the plan dataframe before searching for the requested plan number.
-        
+
         Args:
-        plan_number (str): The plan number to search for.
+        plan_number (Union[str, Number]): The plan number to search for (e.g., '01', 1, or 1.0).
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
-        
+
         Returns:
         Optional[str]: The full path of the plan file if found, None otherwise.
-        
+
         Raises:
         RuntimeError: If the project is not initialized.
 
@@ -487,9 +497,14 @@ class RasPlan:
         ...     print(f"Plan file found at: {plan_path}")
         ... else:
         ...     print("Plan file not found.")
+        >>> # Integer input also works
+        >>> plan_path = ras_plan.get_plan_path(1)
         """
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
+
+        # Normalize plan number to two-digit format
+        plan_number = RasUtils.normalize_ras_number(plan_number)
         
         plan_df = ras_obj.get_plan_entries()
         
@@ -505,12 +520,12 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def get_flow_path(flow_number: str, ras_object=None) -> Optional[str]:
+    def get_flow_path(flow_number: Union[str, Number], ras_object=None) -> Optional[str]:
         """
         Return the full path for a given flow number.
 
         Args:
-        flow_number (str): The flow number to search for.
+        flow_number (Union[str, Number]): The flow number to search for (e.g., '01', 1, or 1.0).
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
 
         Returns:
@@ -526,9 +541,14 @@ class RasPlan:
         ...     print(f"Flow file found at: {flow_path}")
         ... else:
         ...     print("Flow file not found.")
+        >>> # Integer input also works
+        >>> flow_path = ras_plan.get_flow_path(1)
         """
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
+
+        # Normalize flow number to two-digit format
+        flow_number = RasUtils.normalize_ras_number(flow_number)
         
         # Use updated flow dataframe
         ras_obj.flow_df = ras_obj.get_prj_entries('Flow')
@@ -542,12 +562,12 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def get_unsteady_path(unsteady_number: str, ras_object=None) -> Optional[str]:
+    def get_unsteady_path(unsteady_number: Union[str, Number], ras_object=None) -> Optional[str]:
         """
         Return the full path for a given unsteady number.
 
         Args:
-        unsteady_number (str): The unsteady number to search for.
+        unsteady_number (Union[str, Number]): The unsteady number to search for (e.g., '01', 1, or 1.0).
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
 
         Returns:
@@ -563,9 +583,14 @@ class RasPlan:
         ...     print(f"Unsteady file found at: {unsteady_path}")
         ... else:
         ...     print("Unsteady file not found.")
+        >>> # Integer input also works
+        >>> unsteady_path = ras_plan.get_unsteady_path(1)
         """
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
+
+        # Normalize unsteady number to two-digit format
+        unsteady_number = RasUtils.normalize_ras_number(unsteady_number)
         
         # Use updated unsteady dataframe
         ras_obj.unsteady_df = ras_obj.get_prj_entries('Unsteady')
@@ -579,12 +604,12 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def get_geom_path(geom_number: Union[str, int], ras_object=None) -> Optional[str]:
+    def get_geom_path(geom_number: Union[str, Number], ras_object=None) -> Optional[str]:
         """
         Return the full path for a given geometry number.
 
         Args:
-        geom_number (Union[str, int]): The geometry number to search for.
+        geom_number (Union[str, Number]): The geometry number to search for (e.g., '01', 1, or 1.0).
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
 
         Returns:
@@ -600,31 +625,21 @@ class RasPlan:
         ...     print(f"Geometry file found at: {geom_path}")
         ... else:
         ...     print("Geometry file not found.")
+        >>> # Integer input also works
+        >>> geom_path = ras_plan.get_geom_path(1)
         """
         logger = get_logger(__name__)
-        
+
         if geom_number is None:
             logger.warning("Provided geometry number is None")
             return None
-            
+
         try:
             ras_obj = ras_object or ras
             ras_obj.check_initialized()
-            
-            # Ensure geom_number is a string with proper formatting
-            if isinstance(geom_number, int):
-                geom_number = f"{geom_number:02d}"
-            elif isinstance(geom_number, str):
-                # Strip any leading zeros and reformat
-                stripped = geom_number.lstrip('0')
-                if not stripped:  # Handle case where input was '0' or '00'
-                    geom_number = '00'
-                else:
-                    geom_number = f"{int(stripped):02d}"
-            else:
-                # Handle unexpected types
-                logger.warning(f"Unexpected type for geom_number: {type(geom_number)}")
-                return None
+
+            # Normalize geometry number to two-digit format
+            geom_number = RasUtils.normalize_ras_number(geom_number)
             
             # Use updated geom dataframe
             ras_obj.geom_df = ras_obj.get_prj_entries('Geom')
@@ -652,14 +667,17 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def clone_plan(template_plan, new_shortid=None, new_title=None, ras_object=None):
+    def clone_plan(template_plan: Union[str, Number], new_shortid=None, new_plan_shortid=None, new_title=None, ras_object=None):
         """
         Create a new plan file based on a template and update the project file.
 
         Parameters:
-        template_plan (str): Plan number to use as template (e.g., '01')
+        template_plan (Union[str, Number]): Plan number to use as template (e.g., '01', 1, or 1.0)
         new_shortid (str, optional): New short identifier for the plan file (max 24 chars).
                                      If not provided, appends '_copy' to original.
+                                     Alias: new_plan_shortid (for improved clarity)
+        new_plan_shortid (str, optional): Alias for new_shortid. If both are provided,
+                                          new_plan_shortid takes precedence.
         new_title (str, optional): New plan title (max 32 chars, updates "Plan Title=" line).
                                    If not provided, keeps original title.
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
@@ -668,21 +686,33 @@ class RasPlan:
         str: New plan number
 
         Example:
-        >>> # Clone with default shortid and title
+        >>> # Clone with default shortid and title (string input)
         >>> new_plan = RasPlan.clone_plan('01')
         >>>
-        >>> # Clone with custom shortid and title
-        >>> new_plan = RasPlan.clone_plan('01',
-        ...                               new_shortid='Steady_v41',
+        >>> # Clone with integer input
+        >>> new_plan = RasPlan.clone_plan(1)
+        >>>
+        >>> # Clone with custom shortid and title (either parameter name works)
+        >>> new_plan = RasPlan.clone_plan('01', new_shortid='Steady_v41',
+        ...                               new_title='Steady Flow - HEC-RAS 4.1')
+        >>> new_plan = RasPlan.clone_plan('01', new_plan_shortid='Steady_v41',
         ...                               new_title='Steady Flow - HEC-RAS 4.1')
 
         Note:
             Both new_shortid and new_title are optional.
+            new_plan_shortid is an alias for new_shortid for improved clarity.
             This function updates the ras object's dataframes after modifying the project structure.
         """
+        # Handle parameter aliasing: new_plan_shortid takes precedence if both provided
+        if new_plan_shortid is not None:
+            new_shortid = new_plan_shortid
+
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
 
+        # Normalize plan number to two-digit format
+        template_plan = RasUtils.normalize_ras_number(template_plan)
+
         # Validate new_title length if provided
         if new_title is not None and len(new_title) > 32:
             raise ValueError(
@@ -739,13 +769,13 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def clone_unsteady(template_unsteady, new_title=None, ras_object=None):
+    def clone_unsteady(template_unsteady: Union[str, Number], new_title=None, ras_object=None):
         """
         Copy unsteady flow files from a template, find the next unsteady number,
         and update the project file accordingly.
 
         Parameters:
-        template_unsteady (str): Unsteady flow number to be used as a template (e.g., '01')
+        template_unsteady (Union[str, Number]): Unsteady flow number to use as template (e.g., '01', 1, or 1.0)
         new_title (str, optional): New flow title (max 32 chars, updates "Flow Title=" line)
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
 
@@ -753,9 +783,12 @@ class RasPlan:
         str: New unsteady flow number (e.g., '03')
 
         Example:
+        >>> # String input
         >>> new_unsteady_num = RasPlan.clone_unsteady('01',
         ...                                           new_title='Unsteady - HEC-RAS 4.1')
         >>> print(f"New unsteady flow file created: u{new_unsteady_num}")
+        >>> # Integer input also works
+        >>> new_unsteady_num = RasPlan.clone_unsteady(1)
 
         Note:
             This function updates the ras object's dataframes after modifying the project structure.
@@ -763,6 +796,9 @@ class RasPlan:
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
 
+        # Normalize unsteady number to two-digit format
+        template_unsteady = RasUtils.normalize_ras_number(template_unsteady)
+
         # Validate new_title length if provided
         if new_title is not None and len(new_title) > 32:
             raise ValueError(
@@ -815,13 +851,13 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def clone_steady(template_flow, new_title=None, ras_object=None):
+    def clone_steady(template_flow: Union[str, Number], new_title=None, ras_object=None):
         """
         Copy steady flow files from a template, find the next flow number,
         and update the project file accordingly.
 
         Parameters:
-        template_flow (str): Flow number to be used as a template (e.g., '01')
+        template_flow (Union[str, Number]): Flow number to use as template (e.g., '01', 1, or 1.0)
         new_title (str, optional): New flow title (max 32 chars, updates "Flow Title=" line)
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
 
@@ -829,9 +865,12 @@ class RasPlan:
         str: New flow number (e.g., '03')
 
         Example:
+        >>> # String input
         >>> new_flow_num = RasPlan.clone_steady('01',
         ...                                      new_title='Steady Flow - HEC-RAS 4.1')
         >>> print(f"New steady flow file created: f{new_flow_num}")
+        >>> # Integer input also works
+        >>> new_flow_num = RasPlan.clone_steady(1)
 
         Note:
             This function updates the ras object's dataframes after modifying the project structure.
@@ -839,6 +878,9 @@ class RasPlan:
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
 
+        # Normalize flow number to two-digit format
+        template_flow = RasUtils.normalize_ras_number(template_flow)
+
         # Validate new_title length if provided
         if new_title is not None and len(new_title) > 32:
             raise ValueError(
@@ -884,24 +926,33 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def clone_geom(template_geom, ras_object=None):
+    def clone_geom(template_geom: Union[str, Number], ras_object=None):
         """
         Copy geometry files from a template, find the next geometry number,
         and update the project file accordingly.
-        
+
         Parameters:
-        template_geom (str): Geometry number to be used as a template (e.g., '01')
+        template_geom (Union[str, Number]): Geometry number to use as template (e.g., '01', 1, or 1.0)
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
-        
+
         Returns:
         str: New geometry number (e.g., '03')
 
+        Example:
+        >>> # String input
+        >>> new_geom_num = RasPlan.clone_geom('01')
+        >>> # Integer input also works
+        >>> new_geom_num = RasPlan.clone_geom(1)
+
         Note:
             This function updates the ras object's dataframes after modifying the project structure.
         """
         ras_obj = ras_object or ras
         ras_obj.check_initialized()
 
+        # Normalize geometry number to two-digit format
+        template_geom = RasUtils.normalize_ras_number(template_geom)
+
         # Update geometry entries without reinitializing the entire project
         ras_obj.geom_df = ras_obj.get_prj_entries('Geom')
 
@@ -1092,17 +1143,26 @@ class RasPlan:
 
         Parameters:
         plan_number_or_path (Union[str, Path]): The plan number (1 to 99) or full path to the plan file
-        geometry_preprocessor (bool, optional): Flag for Geometry Preprocessor
-        unsteady_flow_simulation (bool, optional): Flag for Unsteady Flow Simulation
-        run_sediment (bool, optional): Flag for run_sediment
-        post_processor (bool, optional): Flag for Post Processor
-        floodplain_mapping (bool, optional): Flag for Floodplain Mapping
+        geometry_preprocessor (bool, optional): Set Geometry Preprocessor (Run HTab, -1 = ON, 0 = OFF)
+        unsteady_flow_simulation (bool, optional): Set Unsteady Flow (Run UNet, -1 = ON, 0 = OFF)
+        run_sediment (bool, optional): Set Run Sediment (Run Sediment, -1 = ON, 0 = OFF)
+        post_processor (bool, optional): Set Post Processor (Run PostProcess, -1 = ON, 0 = OFF)
+        floodplain_mapping (bool, optional): Set Floodplain Mapping (Run RASMapper, -1 = ON, 0 = OFF)
         ras_object (RasPrj, optional): Specific RAS object to use. If None, uses the global ras instance.
 
         Raises:
         ValueError: If the plan file is not found
         IOError: If there's an error reading or writing the plan file
 
+        Notes:
+        - -1 is ON, 0 is OFF
+        - Lines affected in plan file:
+            Run HTab= -1           # geometry_preprocessor
+            Run UNet= -1           # unsteady_flow_simulation
+            Run Sediment= 0        # run_sediment
+            Run PostProcess= -1    # post_processor
+            Run RASMapper= 0       # floodplain_mapping
+
         Example:
         >>> RasPlan.update_run_flags("01", geometry_preprocessor=True, unsteady_flow_simulation=True, run_sediment=False, post_processor=True, floodplain_mapping=False)
         """
@@ -1115,36 +1175,52 @@ class RasPlan:
             if plan_file_path is None or not Path(plan_file_path).exists():
                 raise ValueError(f"Plan file not found: {plan_file_path}")
 
-        flag_mapping = {
-            'geometry_preprocessor': ('Run HTab', geometry_preprocessor),
-            'unsteady_flow_simulation': ('Run UNet', unsteady_flow_simulation),
-            'run_sediment': ('Run run_sediment', run_sediment),
-            'post_processor': ('Run PostProcess', post_processor),
-            'floodplain_mapping': ('Run RASMapper', floodplain_mapping)
-        }
+        # Map arguments to plan keys (string in file : argument, ON=-1, OFF=0)
+        flag_map = [
+            ("Run HTab", geometry_preprocessor),
+            ("Run UNet", unsteady_flow_simulation),
+            ("Run Sediment", run_sediment),
+            ("Run PostProcess", post_processor),
+            ("Run RASMapper", floodplain_mapping)
+        ]
 
         try:
-            with open(plan_file_path, 'r') as file:
-                lines = file.readlines()
+            with open(plan_file_path, 'r') as f:
+                lines = f.readlines()
 
-            for i, line in enumerate(lines):
-                for key, (file_key, value) in flag_mapping.items():
-                    if value is not None and line.strip().startswith(file_key):
-                        lines[i] = f"{file_key}= {1 if value else 0}\n"
+            # Annotate which flags got edited for logger
+            updated_lines = 0
 
-            with open(plan_file_path, 'w') as file:
-                file.writelines(lines)
+            for flag, value in flag_map:
+                if value is not None:
+                    # Find and update the line
+                    found = False
+                    for idx, line in enumerate(lines):
+                        if line.strip().startswith(f"{flag}="):
+                            lines[idx] = f"{flag}= {-1 if value else 0}\n"
+                            updated_lines += 1
+                            found = True
+                            break
+                    if not found:
+                        # If not present, add the line at end (optional; original HEC-RAS behavior retains missing as OFF)
+                        lines.append(f"{flag}= {-1 if value else 0}\n")
+                        updated_lines += 1
 
-            logger = logging.getLogger(__name__)
-            logger.info(f"Successfully updated run flags in plan file: {plan_file_path}")
+            with open(plan_file_path, 'w') as f:
+                f.writelines(lines)
+
+            logger = get_logger(__name__)
+            logger.info(
+                f"Successfully updated run flags in plan file: {plan_file_path} "
+                f"(flags modified: {updated_lines})"
+            )
 
         except IOError as e:
-            logger = logging.getLogger(__name__)
+            logger = get_logger(__name__)
             logger.error(f"Error updating run flags in plan file {plan_file_path}: {e}")
             raise
 
 
-
     @staticmethod
     @log_call
     def update_plan_intervals(
@@ -1223,67 +1299,11 @@ class RasPlan:
             logger = logging.getLogger(__name__)
             logger.error(f"Error updating intervals in plan file {plan_file_path}: {e}")
             raise
+     
+     
 
 
-    @log_call
-    def update_plan_description(plan_number_or_path: Union[str, Path], description: str, ras_object: Optional['RasPrj'] = None) -> None:
-        """
-        Update the description block in a HEC-RAS plan file.
 
-        Args:
-            plan_number_or_path (Union[str, Path]): The plan number or full path to the plan file
-            description (str): The new description text to set
-            ras_object (Optional[RasPrj]): Specific RAS object to use. If None, uses the global ras instance.
-
-        Raises:
-            ValueError: If the plan file is not found
-            IOError: If there's an error reading or writing the plan file
-        """
-        logger = get_logger(__name__)
-        ras_obj = ras_object or ras
-        ras_obj.check_initialized()
-
-        plan_file_path = Path(plan_number_or_path)
-        if not plan_file_path.is_file():
-            plan_file_path = RasUtils.get_plan_path(plan_number_or_path, ras_object)
-            if not plan_file_path.exists():
-                logger.error(f"Plan file not found: {plan_file_path}")
-                raise ValueError(f"Plan file not found: {plan_file_path}")
-
-        try:
-            with open(plan_file_path, 'r') as file:
-                content = file.read()
-
-            # Find the description block
-            desc_pattern = r'Begin DESCRIPTION.*?END DESCRIPTION'
-            new_desc_block = f'Begin DESCRIPTION\n{description}\nEND DESCRIPTION'
-
-            if re.search(desc_pattern, content, re.DOTALL):
-                # Replace existing description block
-                new_content = re.sub(desc_pattern, new_desc_block, content, flags=re.DOTALL)
-            else:
-                # Add new description block at the start of the file
-                new_content = new_desc_block + '\n' + content
-
-            # Write the updated content back to the file
-            with open(plan_file_path, 'w') as file:
-                file.write(new_content)
-
-            logger.info(f"Updated description in plan file: {plan_file_path}")
-
-            # Update the dataframes in the RAS object to reflect changes
-            if ras_object:
-                ras_object.plan_df = ras_object.get_plan_entries()
-                ras_object.geom_df = ras_object.get_geom_entries()
-                ras_object.flow_df = ras_object.get_flow_entries()
-                ras_object.unsteady_df = ras_object.get_unsteady_entries()
-
-        except IOError as e:
-            logger.error(f"Error updating plan description in {plan_file_path}: {e}")
-            raise
-        except Exception as e:
-            logger.error(f"Unexpected error updating plan description: {e}")
-            raise
 
     @staticmethod
     @log_call
@@ -1338,11 +1358,195 @@ class RasPlan:
         return description
 
 
+    @staticmethod
+    @log_call
+    def update_plan_description(plan_number: Union[str, Number], description: str, ras_object=None):
+        """
+        Update or insert plan description in the correct location within a plan file.
+
+        The description block will be placed after initial plan parameters
+        (Plan Title, Program Version, Short Identifier, Simulation Date, Geom File,
+        Flow File, and flow type) but before the Computation Interval line.
+
+        Parameters:
+        -----------
+        plan_number : Union[str, Number]
+            Plan number to update (e.g., '01', 1, or 1.0)
+        description : str
+            Description text to insert. Will be automatically wrapped in
+            BEGIN DESCRIPTION/END DESCRIPTION blocks.
+        ras_object : RasPrj, optional
+            RAS project object. If None, uses global 'ras' object.
+        
+        Returns:
+        --------
+        bool : True if successful, False otherwise
+        
+        Examples:
+        ---------
+        >>> RasPlan.update_plan_description('02', 
+        ...     'Atlas 14 Uncertainty Analysis\\n' +
+        ...     'AEP: 100 years\\n' +
+        ...     'Duration: 24 hours\\n' +
+        ...     'Confidence Level: upper')
+        True
+        """
+        try:
+            # Get the RAS object
+            if ras_object is None:
+                ras_obj = ras
+            else:
+                ras_obj = ras_object
+            
+            # Get plan path
+            plan_path = RasPlan.get_plan_path(plan_number, ras_object=ras_obj)
+            
+            # Read the plan file
+            with open(plan_path, 'r') as f:
+                lines = f.readlines()
+            
+            # Find existing description block if it exists
+            desc_start_idx = None
+            desc_end_idx = None
+            
+            for i, line in enumerate(lines):
+                if line.strip().upper().startswith('BEGIN DESCRIPTION'):
+                    desc_start_idx = i
+                elif line.strip().upper().startswith('END DESCRIPTION'):
+                    desc_end_idx = i
+                    break
+            
+            # Find the correct insertion point (before Computation Interval)
+            insertion_idx = None
+            
+            # Primary method: Find Computation Interval line
+            for i, line in enumerate(lines):
+                if line.strip().startswith('Computation Interval='):
+                    insertion_idx = i
+                    break
+            
+            # Fallback method 1: Look for common parameter lines that come after description
+            if insertion_idx is None:
+                fallback_markers = [
+                    'K Sum by GR=',
+                    'Std Step Tol=',
+                    'Critical Tol=',
+                    'Num of Std Step Trials=',
+                    'Max Error Tol=',
+                    'Flow Tol Ratio=',
+                    'Split Flow NTrial=',
+                    'Split Flow Tol=',
+                    'Split Flow Ratio=',
+                    'Log Output Level=',
+                    'Friction Slope Method=',
+                    'Unsteady Friction Slope Method='
+                ]
+                
+                for i, line in enumerate(lines):
+                    for marker in fallback_markers:
+                        if line.strip().startswith(marker):
+                            insertion_idx = i
+                            break
+                    if insertion_idx is not None:
+                        break
+            
+            # Fallback method 2: Insert after initial parameters and flow type
+            if insertion_idx is None:
+                # Find the last of the initial parameters
+                initial_params = [
+                    'Plan Title=',
+                    'Program Version=',
+                    'Short Identifier=',
+                    'Simulation Date=',
+                    'Geom File=',
+                    'Flow File='
+                ]
+                
+                last_param_idx = 0
+                for i, line in enumerate(lines):
+                    for param in initial_params:
+                        if line.strip().startswith(param):
+                            last_param_idx = max(last_param_idx, i)
+                
+                # Check for flow type lines after Flow File
+                flow_types = ['Subcritical Flow', 'Mixed Flow', 'Supercritical Flow']
+                for i in range(last_param_idx + 1, min(last_param_idx + 5, len(lines))):
+                    if i < len(lines) and lines[i].strip() in flow_types:
+                        last_param_idx = i
+                
+                insertion_idx = last_param_idx + 1
+            
+            # Prepare the new description block
+            # Ensure description doesn't have trailing newline for proper formatting
+            description_clean = description.rstrip()
+
+            description_block = [
+                'Begin DESCRIPTION\n',
+                description_clean + '\n',
+                'END DESCRIPTION\n'
+            ]
+            
+            # Build the new file content
+            if desc_start_idx is not None and desc_end_idx is not None:
+                # Replace existing description block
+                # Keep it in its current location if it's already in the right place
+                # Otherwise move it to the correct location
+                if desc_start_idx < insertion_idx:
+                    # Description is already before insertion point, replace in place
+                    new_lines = lines[:desc_start_idx] + description_block + lines[desc_end_idx + 1:]
+                else:
+                    # Description is after insertion point, need to move it
+                    # Remove old description
+                    lines_without_desc = lines[:desc_start_idx] + lines[desc_end_idx + 1:]
+                    # Insert at correct location
+                    new_lines = lines_without_desc[:insertion_idx] + description_block + lines_without_desc[insertion_idx:]
+            else:
+                # No existing description, insert new one
+                new_lines = lines[:insertion_idx] + description_block + lines[insertion_idx:]
+            
+            # Write the modified content back to the file
+            with open(plan_path, 'w') as f:
+                f.writelines(new_lines)
+            
+            # Validate the result (optional debug check)
+            if __debug__:  # Only in debug mode
+                with open(plan_path, 'r') as f:
+                    content = f.read()
+                
+                # Check that description comes before Computation Interval
+                if 'Begin DESCRIPTION' in content and 'Computation Interval=' in content:
+                    desc_pos = content.find('Begin DESCRIPTION')
+                    comp_pos = content.find('Computation Interval=')
+                    if desc_pos > comp_pos:
+                        print(f"Warning: Description block may be in wrong position in plan {plan_number}")
+            
+            return True
+            
+        except FileNotFoundError:
+            print(f"Error: Plan file not found for plan {plan_number}")
+            return False
+        except IOError as e:
+            print(f"Error: IO error updating plan {plan_number}: {e}")
+            return False
+        except Exception as e:
+            print(f"Error: Unexpected error updating plan {plan_number}: {e}")
+            import traceback
+            traceback.print_exc()
+            return False
+
+
+
+
+
+
+    
+
+
 
 
     @staticmethod
     @log_call
-    def update_simulation_date(plan_number_or_path: Union[str, Path], start_date: datetime, end_date: datetime, ras_object: Optional['RasPrj'] = None) -> None:
+    def update_simulation_date(plan_number_or_path: Union[str, Number, Path], start_date: datetime, end_date: datetime, ras_object: Optional['RasPrj'] = None) -> None:
         """
         Update the simulation date for a given plan.
 
@@ -1400,7 +1604,7 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def get_shortid(plan_number_or_path: Union[str, Path], ras_object=None) -> str:
+    def get_shortid(plan_number_or_path: Union[str, Number, Path], ras_object=None) -> str:
         """
         Get the Short Identifier from a HEC-RAS plan file.
 
@@ -1435,7 +1639,7 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def set_shortid(plan_number_or_path: Union[str, Path], new_shortid: str, ras_object=None) -> None:
+    def set_shortid(plan_number_or_path: Union[str, Number, Path], new_shortid: str, ras_object=None) -> None:
         """
         Set the Short Identifier in a HEC-RAS plan file.
 
@@ -1509,7 +1713,7 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def get_plan_title(plan_number_or_path: Union[str, Path], ras_object=None) -> str:
+    def get_plan_title(plan_number_or_path: Union[str, Number, Path], ras_object=None) -> str:
         """
         Get the Plan Title from a HEC-RAS plan file.
 
@@ -1544,7 +1748,7 @@ class RasPlan:
 
     @staticmethod
     @log_call
-    def set_plan_title(plan_number_or_path: Union[str, Path], new_title: str, ras_object=None) -> None:
+    def set_plan_title(plan_number_or_path: Union[str, Number, Path], new_title: str, ras_object=None) -> None:
         """
         Set the Plan Title in a HEC-RAS plan file.
 
