@@ -10,7 +10,7 @@ try:
     __version__ = version("ras-commander")
 except PackageNotFoundError:
     # package is not installed
-    __version__ = "0.82.0"
+    __version__ = "0.83.2"
 
 # Set up logging
 setup_logging()
@@ -19,12 +19,16 @@ setup_logging()
 from .RasPrj import RasPrj, init_ras_project, get_ras_exe, ras
 from .RasPlan import RasPlan
 from .RasGeo import RasGeo
+from .RasGeometry import RasGeometry
+from .RasGeometryUtils import RasGeometryUtils
 from .RasUnsteady import RasUnsteady
 from .RasUtils import RasUtils
 from .RasExamples import RasExamples
+from .M3Model import M3Model
 from .RasCmdr import RasCmdr
 from .RasControl import RasControl
 from .RasMap import RasMap
+from .RasGuiAutomation import RasGuiAutomation
 from .HdfFluvialPluvial import HdfFluvialPluvial
 
 # HDF handling
@@ -41,6 +45,9 @@ from .HdfXsec import HdfXsec
 from .HdfPump import HdfPump
 from .HdfPipe import HdfPipe
 from .HdfInfiltration import HdfInfiltration
+from .HdfHydraulicTables import HdfHydraulicTables
+from .HdfResultsBreach import HdfResultsBreach
+from .RasBreach import RasBreach
 
 # Plotting functionality
 from .HdfPlot import HdfPlot
@@ -50,14 +57,14 @@ from .HdfResultsPlot import HdfResultsPlot
 __all__ = [
     # Core functionality
     'RasPrj', 'init_ras_project', 'get_ras_exe', 'ras',
-    'RasPlan', 'RasGeo', 'RasUnsteady', 'RasUtils',
-    'RasExamples', 'RasCmdr', 'RasControl', 'RasMap', 'HdfFluvialPluvial',
+    'RasPlan', 'RasGeo', 'RasGeometry', 'RasGeometryUtils', 'RasUnsteady', 'RasUtils',
+    'RasExamples', 'M3Model', 'RasCmdr', 'RasControl', 'RasMap', 'RasGuiAutomation', 'HdfFluvialPluvial',
     
     # HDF handling
     'HdfBase', 'HdfBndry', 'HdfMesh', 'HdfPlan',
     'HdfResultsMesh', 'HdfResultsPlan', 'HdfResultsXsec',
     'HdfStruc', 'HdfUtils', 'HdfXsec', 'HdfPump',
-    'HdfPipe', 'HdfInfiltration',
+    'HdfPipe', 'HdfInfiltration', 'HdfHydraulicTables', 'HdfResultsBreach', 'RasBreach',
     
     # Plotting functionality
     'HdfPlot', 'HdfResultsPlot',
